Table of Contents Management
============================

Commands to create a add, delete a Table of Contents, or to sync it to the most recent chapters.

.. click:: web_novel_scraper.__main__:set_toc_main_url
    :prog: set-toc-main-url
    :nested: full

.. click:: web_novel_scraper.__main__:add_toc_html
    :prog: add-toc-html
    :nested: full

.. click:: web_novel_scraper.__main__:sync_toc
    :prog: sync-toc
    :nested: full
    
.. click:: web_novel_scraper.__main__:delete_toc
    :prog: delete-toc
    :nested: full
    
.. click:: web_novel_scraper.__main__:show_toc
    :prog: show-toc
    :nested: full
    